# n-ext
Project Interface For nextcord-ext

# Projects Currently Added

```
n-ext[menus] newest version of menus
n-ext[events] new version of events
n-ext[alternatives] newest verson of alternatives
n-ext[lava] Also Can Use n-ext[music]
n-ext[core] The newest version of nextcord
n-ext[ipc] newest ipc version
```
